#[repr(C)]pub struct PF_ChannelChunk {
pub channel_ref: PF_ChannelRef,
pub widthL: A_long,
pub heightL: A_long,
pub dimensionL: A_long,
pub row_bytesL: A_long,
pub data_type: PF_DataType,
pub dataH: PF_Handle,
pub dataPV: *mut c_void,
}Expand description
the channel data parallels the image data in size and shape. the width is the number of pixels, the height is the number of scanlines the height is image_height the dimension is the number of planes in a pixel the row_bytes is the length of a scanline in bytes the data type is the type of data in a plane Note : a pixel consists of dimensionL * sizeof(data_type) bytes dataH is a handle to the data. dataPV is a pointer to the dereferenced locked handle effects should always have dataPV non null.
Fields
channel_ref: PF_ChannelRefwidthL: A_longheightL: A_longdimensionL: A_longrow_bytesL: A_longdata_type: PF_DataTypedataH: PF_HandledataPV: *mut c_voidTrait Implementations
Sourceimpl Clone for PF_ChannelChunk
impl Clone for PF_ChannelChunk
Sourcefn clone(&self) -> PF_ChannelChunk
fn clone(&self) -> PF_ChannelChunk
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PF_ChannelChunk
impl Debug for PF_ChannelChunk
impl Copy for PF_ChannelChunk