#[repr(C)]pub struct PF_PathDef {
pub path_id: PF_PathID,
pub reserved0: A_long,
pub dephault: A_long,
}Expand description
Path – PF_Param_PATH
Path parameters give access to the mask/path/shapes of the layer on which the effect is applied. For more information on how to use these paths, see the PF_PathQuerySuite, and the PF_PathDataSuite in AE_EffectSuites.h
Fields
path_id: PF_PathIDreserved0: A_longdephault: A_longTrait Implementations
Sourceimpl Clone for PF_PathDef
impl Clone for PF_PathDef
Sourcefn clone(&self) -> PF_PathDef
fn clone(&self) -> PF_PathDef
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PF_PathDef
impl Debug for PF_PathDef
impl Copy for PF_PathDef