PrSDKAudioSuite

Struct PrSDKAudioSuite 

#[repr(C)]
pub struct PrSDKAudioSuite { pub ConvertAndInterleaveTo8BitInteger: Option<unsafe extern "C" fn(inSource: *mut *mut f32, inDestination: *mut c_char, inNumChannels: c_uint, inNumSampleFrames: c_uint) -> prSuiteError>, pub ConvertAndInterleaveTo16BitInteger: Option<unsafe extern "C" fn(inSource: *mut *mut f32, inDestination: *mut c_short, inNumChannels: c_uint, inNumSampleFrames: c_uint) -> prSuiteError>, pub ConvertAndInterleaveTo24BitInteger: Option<unsafe extern "C" fn(inSource: *mut *mut f32, inDestination: *mut c_char, inNumChannels: c_uint, inNumSampleFrames: c_uint) -> prSuiteError>, pub ConvertAndInterleaveTo32BitInteger: Option<unsafe extern "C" fn(inSource: *mut *mut f32, inDestination: *mut csSDK_int32, inNumChannels: c_uint, inNumSampleFrames: c_uint) -> prSuiteError>, pub UninterleaveAndConvertFrom8BitInteger: Option<unsafe extern "C" fn(inSource: *mut c_char, inDestination: *mut *mut f32, inNumChannels: c_uint, inNumSampleFrames: c_uint) -> prSuiteError>, pub UninterleaveAndConvertFrom16BitInteger: Option<unsafe extern "C" fn(inSource: *mut c_short, inDestination: *mut *mut f32, inNumChannels: c_uint, inNumSampleFrames: c_uint) -> prSuiteError>, pub UninterleaveAndConvertFrom24BitInteger: Option<unsafe extern "C" fn(inSource: *mut c_char, inDestination: *mut *mut f32, inNumChannels: c_uint, inNumSampleFrames: c_uint) -> prSuiteError>, pub UninterleaveAndConvertFrom32BitInteger: Option<unsafe extern "C" fn(inSource: *mut csSDK_int32, inDestination: *mut *mut f32, inNumChannels: c_uint, inNumSampleFrames: c_uint) -> prSuiteError>, }

Fields

ConvertAndInterleaveTo8BitInteger: Option<unsafe extern "C" fn(inSource: *mut *mut f32, inDestination: *mut c_char, inNumChannels: c_uint, inNumSampleFrames: c_uint) -> prSuiteError>

These are a variety of audio buffer conversion routines to convert an array of floating point buffers into interleaved audio of a specific type.

@param inSource An array of float buffers holding audio. @param inDestination A single buffer to hold the converted, interleaved audio. inDestination must be at least inNumChannels * sizeof(destinationFormat) * inNumSampleFrames bytes long. @param inNumChannels The number of channels in inSource. @param inNumSampleFrames The number of samples in each buffer in inSource.

ConvertAndInterleaveTo16BitInteger: Option<unsafe extern "C" fn(inSource: *mut *mut f32, inDestination: *mut c_short, inNumChannels: c_uint, inNumSampleFrames: c_uint) -> prSuiteError>ConvertAndInterleaveTo24BitInteger: Option<unsafe extern "C" fn(inSource: *mut *mut f32, inDestination: *mut c_char, inNumChannels: c_uint, inNumSampleFrames: c_uint) -> prSuiteError>ConvertAndInterleaveTo32BitInteger: Option<unsafe extern "C" fn(inSource: *mut *mut f32, inDestination: *mut csSDK_int32, inNumChannels: c_uint, inNumSampleFrames: c_uint) -> prSuiteError>UninterleaveAndConvertFrom8BitInteger: Option<unsafe extern "C" fn(inSource: *mut c_char, inDestination: *mut *mut f32, inNumChannels: c_uint, inNumSampleFrames: c_uint) -> prSuiteError>

These routines provide the reverse of the routines above, converting and uninterleaving a single buffer in a specified type.

@param inSource A single buffer holding the orignal, interleaved audio. @param inDestination An array of float buffers holding audio. There must be inNumChannels buffers allocated in the array, and each must be at least inNumSampleFrames * sizeof(float) bytes long. @param inNumChannels The number of channels in inSource. @param inNumSampleFrames The number of samples in each buffer in inSource.

UninterleaveAndConvertFrom16BitInteger: Option<unsafe extern "C" fn(inSource: *mut c_short, inDestination: *mut *mut f32, inNumChannels: c_uint, inNumSampleFrames: c_uint) -> prSuiteError>UninterleaveAndConvertFrom24BitInteger: Option<unsafe extern "C" fn(inSource: *mut c_char, inDestination: *mut *mut f32, inNumChannels: c_uint, inNumSampleFrames: c_uint) -> prSuiteError>UninterleaveAndConvertFrom32BitInteger: Option<unsafe extern "C" fn(inSource: *mut csSDK_int32, inDestination: *mut *mut f32, inNumChannels: c_uint, inNumSampleFrames: c_uint) -> prSuiteError>