#[repr(C, packed(1))]pub struct PrSDKPPixCacheSuite {Show 20 fields
pub AddFrameToCache: Option<unsafe extern "C" fn(inImporterID: csSDK_uint32, inStreamIndex: csSDK_int32, inPPixHand: PPixHand, inFrameNumber: csSDK_int32, inPreferences: *mut c_void, inPreferencesLength: csSDK_int32) -> prSuiteError>,
pub GetFrameFromCache: Option<unsafe extern "C" fn(inImporterID: csSDK_uint32, inStreamIndex: csSDK_int32, inFrameNumber: csSDK_int32, inNumFormats: csSDK_int32, inFormats: *mut imFrameFormat, outPPixHand: *mut PPixHand, inPreferences: *mut c_void, inPreferencesLength: csSDK_int32) -> prSuiteError>,
pub AddRawPPixToCache: Option<unsafe extern "C" fn(inImporterID: csSDK_uint32, inPPixHand: PPixHand, inKey: csSDK_int32) -> prSuiteError>,
pub GetRawPPixFromCache: Option<unsafe extern "C" fn(inImporterID: csSDK_uint32, inKey: csSDK_int32, outPPixHand: *mut PPixHand) -> prSuiteError>,
pub AddNamedPPixToCache: Option<unsafe extern "C" fn(inPPixIdentifier: *const prPluginID, inPPix: PPixHand) -> prSuiteError>,
pub GetNamedPPixFromCache: Option<unsafe extern "C" fn(inPPixIdentifier: *const prPluginID, outPPixHand: *mut PPixHand) -> prSuiteError>,
pub RegisterDependencyOnNamedPPix: Option<unsafe extern "C" fn(inPPixIdentifier: *const prPluginID) -> prSuiteError>,
pub UnregisterDependencyOnNamedPPix: Option<unsafe extern "C" fn(inPPixIdentifier: *const prPluginID) -> prSuiteError>,
pub ExpireNamedPPixFromCache: Option<unsafe extern "C" fn(inPPixIdentifier: *const prPluginID) -> prSuiteError>,
pub ExpireAllPPixesFromCache: Option<unsafe extern "C" fn() -> prSuiteError>,
pub AddFrameToCacheWithColorProfile: Option<unsafe extern "C" fn(inImporterID: csSDK_uint32, inStreamIndex: csSDK_int32, inPPixHand: PPixHand, inFrameNumber: csSDK_int32, inPreferences: *mut c_void, inPreferencesLength: csSDK_int32, inColorProfileName: *mut PrSDKString, inColorProfileData: *mut c_void, inColorProfileDataLength: csSDK_int32) -> prSuiteError>,
pub GetFrameFromCacheWithColorProfile: Option<unsafe extern "C" fn(inImporterID: csSDK_uint32, inStreamIndex: csSDK_int32, inFrameNumber: csSDK_int32, inNumFormats: csSDK_int32, inFormats: *mut imFrameFormat, outPPixHand: *mut PPixHand, inPreferences: *mut c_void, inPreferencesLength: csSDK_int32, inColorProfileName: *mut PrSDKString, inColorProfileData: *mut c_void, inColorProfileDataSize: csSDK_int32) -> prSuiteError>,
pub AddFrameToCacheWithColorProfile2: Option<unsafe extern "C" fn(inImporterID: csSDK_uint32, inStreamIndex: csSDK_int32, inPPixHand: PPixHand, inFrameNumber: csSDK_int32, inQuality: PrRenderQuality, inPreferences: *mut c_void, inPreferencesLength: csSDK_int32, inColorProfileName: *mut PrSDKString, inColorProfileData: *mut c_void, inColorProfileDataLength: csSDK_int32) -> prSuiteError>,
pub GetFrameFromCacheWithColorProfile2: Option<unsafe extern "C" fn(inImporterID: csSDK_uint32, inStreamIndex: csSDK_int32, inFrameNumber: csSDK_int32, inNumFormats: csSDK_int32, inFormats: *mut imFrameFormat, outPPixHand: *mut PPixHand, inQuality: PrRenderQuality, inPreferences: *mut c_void, inPreferencesLength: csSDK_int32, inColorProfileName: *mut PrSDKString, inColorProfileData: *mut c_void, inColorProfileDataSize: csSDK_int32) -> prSuiteError>,
pub AddFrameToCacheWithColorSpace: Option<unsafe extern "C" fn(inImporterID: csSDK_uint32, inStreamIndex: csSDK_int32, inPPixHand: PPixHand, inFrameNumber: csSDK_int32, inQuality: PrRenderQuality, inPreferences: *mut c_void, inPreferencesLength: csSDK_int32, inPrColorSpaceID: *mut PrSDKColorSpaceID) -> prSuiteError>,
pub GetFrameFromCacheWithColorSpace: Option<unsafe extern "C" fn(inImporterID: csSDK_uint32, inStreamIndex: csSDK_int32, inFrameNumber: csSDK_int32, inNumFormats: csSDK_int32, inFormats: *mut imFrameFormat, outPPixHand: *mut PPixHand, inQuality: PrRenderQuality, inPreferences: *mut c_void, inPreferencesLength: csSDK_int32, inPrColorSpaceID: *mut PrSDKColorSpaceID) -> prSuiteError>,
pub RegisterDependencyOnFrame: Option<unsafe extern "C" fn(inImporterID: csSDK_uint32, inStreamIndex: csSDK_int32, inFrameNumber: csSDK_int32, inNumFormats: csSDK_int32, inFormats: *mut imFrameFormat, outPPixIdentifier: *mut prPluginID, inPreferences: *mut c_void, inPreferencesLength: csSDK_int32) -> prSuiteError>,
pub RegisterDependencyOnFrameWithColorProfile: Option<unsafe extern "C" fn(inImporterID: csSDK_uint32, inStreamIndex: csSDK_int32, inFrameNumber: csSDK_int32, inNumFormats: csSDK_int32, inFormats: *mut imFrameFormat, outPPixIdentifier: *mut prPluginID, inPreferences: *mut c_void, inPreferencesLength: csSDK_int32, inColorProfileName: *mut PrSDKString, inColorProfileData: *mut c_void, inColorProfileDataSize: csSDK_int32) -> prSuiteError>,
pub RegisterDependencyOnFrameWithColorProfile2: Option<unsafe extern "C" fn(inImporterID: csSDK_uint32, inStreamIndex: csSDK_int32, inFrameNumber: csSDK_int32, inNumFormats: csSDK_int32, inFormats: *mut imFrameFormat, inQuality: PrRenderQuality, outPPixIdentifier: *mut prPluginID, inPreferences: *mut c_void, inPreferencesLength: csSDK_int32, inColorProfileName: *mut PrSDKString, inColorProfileData: *mut c_void, inColorProfileDataSize: csSDK_int32) -> prSuiteError>,
pub RegisterDependencyOnFrameWithColorSpace: Option<unsafe extern "C" fn(inImporterID: csSDK_uint32, inStreamIndex: csSDK_int32, inFrameNumber: csSDK_int32, inNumFormats: csSDK_int32, inFormats: *mut imFrameFormat, inQuality: PrRenderQuality, outPPixIdentifier: *mut prPluginID, inPreferences: *mut c_void, inPreferencesLength: csSDK_int32, inPrColorSpaceID: *mut PrSDKColorSpaceID) -> prSuiteError>,
}Fields
AddFrameToCache: Option<unsafe extern "C" fn(inImporterID: csSDK_uint32, inStreamIndex: csSDK_int32, inPPixHand: PPixHand, inFrameNumber: csSDK_int32, inPreferences: *mut c_void, inPreferencesLength: csSDK_int32) -> prSuiteError>This will add the ppix to the frame cache for this importer instance and stream.
@param inImporterID The ID of this importer instance (passed down in imGetInfo8). @param inStreamIndex The index of this stream @param inPPixHand The ppix handle you want to add. @param inFrameNumber The frame number of the ppix. @param inPreferences Current importer preferences, can be NULL for no preferences @param inPreferencesLength Current importer preferences length
GetFrameFromCache: Option<unsafe extern "C" fn(inImporterID: csSDK_uint32, inStreamIndex: csSDK_int32, inFrameNumber: csSDK_int32, inNumFormats: csSDK_int32, inFormats: *mut imFrameFormat, outPPixHand: *mut PPixHand, inPreferences: *mut c_void, inPreferencesLength: csSDK_int32) -> prSuiteError>This will retrieve a ppix from the frame cache for this importer instance and stream.
@param inImporterID The ID of this importer instance (passed down in imGetInfo8). @param inStreamIndex The index of this stream @param inFrameNumber The frame number of the ppix requested. @param outPPixHand A pointer to a ppix handle to hold the retrieved frame. @param inPreferences Current importer preferences, can be NULL for no preferences @param inPreferencesLength Current importer preferences length
AddRawPPixToCache: Option<unsafe extern "C" fn(inImporterID: csSDK_uint32, inPPixHand: PPixHand, inKey: csSDK_int32) -> prSuiteError>This will add the ppix to the raw cache for this importer instance.
@param inImporterID The ID of this importer instance (passed down in imGetInfo8). @param inPPixHand The raw ppix handle you want to add. @param inKey The key to use for this raw ppix. If an entry with this key already exists, this call will fail.
GetRawPPixFromCache: Option<unsafe extern "C" fn(inImporterID: csSDK_uint32, inKey: csSDK_int32, outPPixHand: *mut PPixHand) -> prSuiteError>This will retrieve a ppix from the frame cache for this importer instance.
@param inImporterID The ID of this importer instance (passed down in imGetInfo8). @param inKey The key to identify this raw ppix. @param outPPixHand A pointer to a ppix handle to hold the retrieved frame.
AddNamedPPixToCache: Option<unsafe extern "C" fn(inPPixIdentifier: *const prPluginID, inPPix: PPixHand) -> prSuiteError>This function allows you to cache a PPix using a GUID as an identifier.
@param inPPixIdentifier The ID of the PPix, used to identify this particular set of pixels. The GUID can be anything, but must be unique. @param inPPix The Pixels to put in the cache. If a frame with this id is already in the cache, then this PPix will be ignored. You still have ownership over the PPix. You may want to get the PPix from the cache after this, in case your frame is redundant.
GetNamedPPixFromCache: Option<unsafe extern "C" fn(inPPixIdentifier: *const prPluginID, outPPixHand: *mut PPixHand) -> prSuiteError>This function retrieves a named PPix from the cache.
@param inPPixIdentifier The ID of the PPix. @param outPPixHand The PPix, if it’s available. If it’s not in the cache, this will be NULL. You are responsible for calling PPixDispose on this PPix, like any other.
RegisterDependencyOnNamedPPix: Option<unsafe extern "C" fn(inPPixIdentifier: *const prPluginID) -> prSuiteError>This function registers a dependency on a PPix. If a frame with that identifier is in the cache now, or ends up in the cache soon, then it will not be flushed from the cache while there are outstanding dependencies. You are responsible for call the Unregister function - if you don’t then this is the same as a memory leak of a PPix.
@param inPPixIdentifier The ID of the PPix you want held in the cache.
UnregisterDependencyOnNamedPPix: Option<unsafe extern "C" fn(inPPixIdentifier: *const prPluginID) -> prSuiteError>This function unregisters a dependency on a named PPix. This must be called for every successful call of RegisterDependencyOnNamedPPix
@param inPPixIdentifier The ID of the PPix you no longer need in the cache.
ExpireNamedPPixFromCache: Option<unsafe extern "C" fn(inPPixIdentifier: *const prPluginID) -> prSuiteError>This function attempts to flush a frame from the cache. If the frame has a registered dependency, then the frame will remain available until the dependency count hits zero.
@param inPPixIdentifier The ID of the PPix you want forcibly removed from the cache.
ExpireAllPPixesFromCache: Option<unsafe extern "C" fn() -> prSuiteError>This function attempts to flush all ppixes from the cache.
AddFrameToCacheWithColorProfile: Option<unsafe extern "C" fn(inImporterID: csSDK_uint32, inStreamIndex: csSDK_int32, inPPixHand: PPixHand, inFrameNumber: csSDK_int32, inPreferences: *mut c_void, inPreferencesLength: csSDK_int32, inColorProfileName: *mut PrSDKString, inColorProfileData: *mut c_void, inColorProfileDataLength: csSDK_int32) -> prSuiteError>This will add the ppix to the frame cache for this importer instance and stream.
@param inImporterID The ID of this importer instance (passed down in imGetInfo8). @param inStreamIndex The index of this stream @param inPPixHand The ppix handle you want to add. @param inFrameNumber The frame number of the ppix. @param inPreferences Current importer preferences, can be NULL for no preferences @param inPreferencesLength Current importer preferences length @param inColorProfileName The name of the selected color profile. This is only worth providing if your Importer supports color management, and has more than one possible profile. Otherwise we will default to the single profile provided. @param inColorProfileData This is completely optional. We will use the color profile data provided through the imGetIndColorProfile selector. In some future version we will allow Importers to support arbitrary profiles, at which point this param will be useful.
GetFrameFromCacheWithColorProfile: Option<unsafe extern "C" fn(inImporterID: csSDK_uint32, inStreamIndex: csSDK_int32, inFrameNumber: csSDK_int32, inNumFormats: csSDK_int32, inFormats: *mut imFrameFormat, outPPixHand: *mut PPixHand, inPreferences: *mut c_void, inPreferencesLength: csSDK_int32, inColorProfileName: *mut PrSDKString, inColorProfileData: *mut c_void, inColorProfileDataSize: csSDK_int32) -> prSuiteError>This will retrieve a ppix from the frame cache for this importer instance and stream.
@param inImporterID The ID of this importer instance (passed down in imGetInfo8). @param inStreamIndex The index of this stream @param inFrameNumber The frame number of the ppix requested. @param outPPixHand A pointer to a ppix handle to hold the retrieved frame. @param inPreferences Current importer preferences, can be NULL for no preferences @param inPreferencesLength Current importer preferences length @param inColorProfileName The name of the selected color profile. This is only worth providing if your Importer supports color management, and has more than one possible profile. Otherwise we will default to the single profile provided. @param inColorProfileData This is completely optional. We will use the color profile data provided through the imGetIndColorProfile selector. In some future version we will allow Importers to support arbitrary profiles, at which point this param will be useful.
AddFrameToCacheWithColorProfile2: Option<unsafe extern "C" fn(inImporterID: csSDK_uint32, inStreamIndex: csSDK_int32, inPPixHand: PPixHand, inFrameNumber: csSDK_int32, inQuality: PrRenderQuality, inPreferences: *mut c_void, inPreferencesLength: csSDK_int32, inColorProfileName: *mut PrSDKString, inColorProfileData: *mut c_void, inColorProfileDataLength: csSDK_int32) -> prSuiteError>This will add the ppix to the frame cache for this importer instance and stream.
@param inImporterID The ID of this importer instance (passed down in imGetInfo8). @param inStreamIndex The index of this stream @param inPPixHand The ppix handle you want to add. @param inFrameNumber The frame number of the ppix. @param inPreferences Current importer preferences, can be NULL for no preferences @param inPreferencesLength Current importer preferences length @param inColorProfileName The name of the selected color profile. This is only worth providing if your Importer supports color management, and has more than one possible profile. Otherwise we will default to the single profile provided. @param inColorProfileData This is completely optional. We will use the color profile data provided through the imGetIndColorProfile selector. In some future version we will allow Importers to support arbitrary profiles, at which point this param will be useful.
GetFrameFromCacheWithColorProfile2: Option<unsafe extern "C" fn(inImporterID: csSDK_uint32, inStreamIndex: csSDK_int32, inFrameNumber: csSDK_int32, inNumFormats: csSDK_int32, inFormats: *mut imFrameFormat, outPPixHand: *mut PPixHand, inQuality: PrRenderQuality, inPreferences: *mut c_void, inPreferencesLength: csSDK_int32, inColorProfileName: *mut PrSDKString, inColorProfileData: *mut c_void, inColorProfileDataSize: csSDK_int32) -> prSuiteError>This will retrieve a ppix from the frame cache for this importer instance and stream.
@param inImporterID The ID of this importer instance (passed down in imGetInfo8). @param inStreamIndex The index of this stream @param inFrameNumber The frame number of the ppix requested. @param outPPixHand A pointer to a ppix handle to hold the retrieved frame. @param inPreferences Current importer preferences, can be NULL for no preferences @param inPreferencesLength Current importer preferences length @param inColorProfileName The name of the selected color profile. This is only worth providing if your Importer supports color management, and has more than one possible profile. Otherwise we will default to the single profile provided. @param inColorProfileData This is completely optional. We will use the color profile data provided through the imGetIndColorProfile selector. In some future version we will allow Importers to support arbitrary profiles, at which point this param will be useful.
AddFrameToCacheWithColorSpace: Option<unsafe extern "C" fn(inImporterID: csSDK_uint32, inStreamIndex: csSDK_int32, inPPixHand: PPixHand, inFrameNumber: csSDK_int32, inQuality: PrRenderQuality, inPreferences: *mut c_void, inPreferencesLength: csSDK_int32, inPrColorSpaceID: *mut PrSDKColorSpaceID) -> prSuiteError>This will add the ppix to the frame cache for this importer instance and stream.
@param inImporterID The ID of this importer instance (passed down in imGetInfo8). @param inStreamIndex The index of this stream @param inPPixHand The ppix handle you want to add. @param inFrameNumber The frame number of the ppix. @param inQuality The quality level with which to render the frame @param inPreferences Current importer preferences, can be NULL for no preferences @param inPreferencesLength Current importer preferences length @param inPrColorSpaceID color space for the frame to be cached; this is an opaque token passed to the importer by the host that importer is expected to use in color management APIs
GetFrameFromCacheWithColorSpace: Option<unsafe extern "C" fn(inImporterID: csSDK_uint32, inStreamIndex: csSDK_int32, inFrameNumber: csSDK_int32, inNumFormats: csSDK_int32, inFormats: *mut imFrameFormat, outPPixHand: *mut PPixHand, inQuality: PrRenderQuality, inPreferences: *mut c_void, inPreferencesLength: csSDK_int32, inPrColorSpaceID: *mut PrSDKColorSpaceID) -> prSuiteError>This will retrieve a ppix from the frame cache for this importer instance and stream.
@param inImporterID The ID of this importer instance (passed down in imGetInfo8). @param inStreamIndex The index of this stream @param inFrameNumber The frame number of the ppix requested. @param inNumFormats The number of frame formats @param inFormats The array of frame formats @param outPPixHand A pointer to a ppix handle to hold the retrieved frame. @param inQuality The quality level with which to render the frame @param inPreferences Current importer preferences, can be NULL for no preferences @param inPreferencesLength Current importer preferences length @param inPrColorSpaceID color space to be used as part of identifier to retrieve a frame from cache; this is an opaque token passed to the importer by the host that importer is expected to use in color management APIs
RegisterDependencyOnFrame: Option<unsafe extern "C" fn(inImporterID: csSDK_uint32, inStreamIndex: csSDK_int32, inFrameNumber: csSDK_int32, inNumFormats: csSDK_int32, inFormats: *mut imFrameFormat, outPPixIdentifier: *mut prPluginID, inPreferences: *mut c_void, inPreferencesLength: csSDK_int32) -> prSuiteError>This function registers a dependency on a PPix. If a frame with these settings is in the cache now, or ends up in the cache soon, then it will not be flushed from the cache while there are outstanding dependencies. You are responsible for calling the UnregisterDependencyOnNamedPPix function with the returned identifier - if you don’t then this is the same as a memory leak of a PPix.
@param inImporterID The ID of this importer instance (passed down in imGetInfo8). @param inStreamIndex The index of this stream @param inFrameNumber The frame number of the ppix. @param outPPixIdentifier The pointer to the ppix Identifer obtained for the frame @param inPreferences Current importer preferences, can be NULL for no preferences @param inPreferencesLength Current importer preferences length
RegisterDependencyOnFrameWithColorProfile: Option<unsafe extern "C" fn(inImporterID: csSDK_uint32, inStreamIndex: csSDK_int32, inFrameNumber: csSDK_int32, inNumFormats: csSDK_int32, inFormats: *mut imFrameFormat, outPPixIdentifier: *mut prPluginID, inPreferences: *mut c_void, inPreferencesLength: csSDK_int32, inColorProfileName: *mut PrSDKString, inColorProfileData: *mut c_void, inColorProfileDataSize: csSDK_int32) -> prSuiteError>This function registers a dependency on a PPix. If a frame with these settings is in the cache now, or ends up in the cache soon, then it will not be flushed from the cache while there are outstanding dependencies. You are responsible for calling the UnregisterDependencyOnNamedPPix function with the returned identifier - if you don’t then this is the same as a memory leak of a PPix.
@param inImporterID The ID of this importer instance (passed down in imGetInfo8). @param inStreamIndex The index of this stream @param inFrameNumber The frame number of the ppix. @param outPPixIdentifier The pointer to the ppix Identifer obtained for the frame @param inPreferences Current importer preferences, can be NULL for no preferences @param inPreferencesLength Current importer preferences length @param inColorProfileName The name of the selected color profile. This is only worth providing if your Importer supports color management, and has more than one possible profile. Otherwise we will default to the single profile provided. @param inColorProfileData This is completely optional. We will use the color profile data provided through the imGetIndColorProfile selector. In some future version we will allow Importers to support arbitrary profiles, at which point this param will be useful.
RegisterDependencyOnFrameWithColorProfile2: Option<unsafe extern "C" fn(inImporterID: csSDK_uint32, inStreamIndex: csSDK_int32, inFrameNumber: csSDK_int32, inNumFormats: csSDK_int32, inFormats: *mut imFrameFormat, inQuality: PrRenderQuality, outPPixIdentifier: *mut prPluginID, inPreferences: *mut c_void, inPreferencesLength: csSDK_int32, inColorProfileName: *mut PrSDKString, inColorProfileData: *mut c_void, inColorProfileDataSize: csSDK_int32) -> prSuiteError>This function registers a dependency on a PPix. If a frame with these settings is in the cache now, or ends up in the cache soon, then it will not be flushed from the cache while there are outstanding dependencies. You are responsible for calling the UnregisterDependencyOnNamedPPix function with the returned identifier - if you don’t then this is the same as a memory leak of a PPix.
@param inImporterID The ID of this importer instance (passed down in imGetInfo8). @param inStreamIndex The index of this stream @param inFrameNumber The frame number of the ppix. @param outPPixIdentifier The pointer to the ppix Identifer obtained for the frame @param inPreferences Current importer preferences, can be NULL for no preferences @param inPreferencesLength Current importer preferences length @param inColorProfileName The name of the selected color profile. This is only worth providing if your Importer supports color management, and has more than one possible profile. Otherwise we will default to the single profile provided. @param inColorProfileData This is completely optional. We will use the color profile data provided through the imGetIndColorProfile selector. In some future version we will allow Importers to support arbitrary profiles, at which point this param will be useful.
RegisterDependencyOnFrameWithColorSpace: Option<unsafe extern "C" fn(inImporterID: csSDK_uint32, inStreamIndex: csSDK_int32, inFrameNumber: csSDK_int32, inNumFormats: csSDK_int32, inFormats: *mut imFrameFormat, inQuality: PrRenderQuality, outPPixIdentifier: *mut prPluginID, inPreferences: *mut c_void, inPreferencesLength: csSDK_int32, inPrColorSpaceID: *mut PrSDKColorSpaceID) -> prSuiteError>This function registers a dependency on a PPix. If a frame with these settings is in the cache now, or ends up in the cache soon, then it will not be flushed from the cache while there are outstanding dependencies. You are responsible for calling the UnregisterDependencyOnNamedPPix function with the returned identifier - if you don’t then this is the same as a memory leak of a PPix.
@param inImporterID The ID of this importer instance (passed down in imGetInfo8). @param inStreamIndex The index of this stream @param inFrameNumber The frame number of the ppix. @param inNumFormats The number of frame formats @param inFormats The array of frame formats @param inQuality The quality level with which to render the frame @param outPPixIdentifier The pointer to the ppix Identifer obtained for the frame @param inPreferences Current importer preferences, can be NULL for no preferences @param inPreferencesLength Current importer preferences length @param inPrColorSpaceID color space to be used as part of identifier to retrieve a frame from cache; this is an opaque token passed to the importer by the host that importer is expected to use in color management APIs