PrSDKStringSuite

Struct PrSDKStringSuite 

#[repr(C, packed(1))]
pub struct PrSDKStringSuite { pub DisposeString: Option<unsafe extern "C" fn(inSDKString: *const PrSDKString) -> prSuiteError>, pub AllocateFromUTF8: Option<unsafe extern "C" fn(inUTF8String: *const prUTF8Char, outSDKString: *mut PrSDKString) -> prSuiteError>, pub CopyToUTF8String: Option<unsafe extern "C" fn(inSDKString: *const PrSDKString, outUTF8StringBuffer: *mut prUTF8Char, ioUTF8StringBufferSizeInElements: *mut csSDK_uint32) -> prSuiteError>, pub AllocateFromUTF16: Option<unsafe extern "C" fn(inUTF16String: *const prUTF16Char, outSDKString: *mut PrSDKString) -> prSuiteError>, pub CopyToUTF16String: Option<unsafe extern "C" fn(inSDKString: *const PrSDKString, outUTF16StringBuffer: *mut prUTF16Char, ioUTF16StringBufferSizeInElements: *mut csSDK_uint32) -> prSuiteError>, }

Fields

DisposeString: Option<unsafe extern "C" fn(inSDKString: *const PrSDKString) -> prSuiteError>

This will dispose of an SDKString. It is OK to pass in an empty string.

@param inSDKString the string to dispose of

@return suiteError_StringNotFound this string has not been allocated, or may have already been disposed @return suiteError_InvalidParms one of the params is invalid

AllocateFromUTF8: Option<unsafe extern "C" fn(inUTF8String: *const prUTF8Char, outSDKString: *mut PrSDKString) -> prSuiteError>

This will allocate an SDKString from a passed in null terminated string.

@param inUTF8String null terminated UTF8 string to copy into the SDK string @param ioSDKString this passed in SDK string will receive the new allocated string - you must dispose of this sdk string

@return suiteError_StringNotFound this string has not been allocated, or may have already been disposed @return suiteError_InvalidParms one of the params is invalid

CopyToUTF8String: Option<unsafe extern "C" fn(inSDKString: *const PrSDKString, outUTF8StringBuffer: *mut prUTF8Char, ioUTF8StringBufferSizeInElements: *mut csSDK_uint32) -> prSuiteError>

This will copy an SDKString into a UTF8 null terminated string if ioUTF8StringBufferByteCount reports enough bytes in the string buffer to copy. If there are not enough bytes - suiteError_StringBufferTooSmall will be returned and ioUTF8StringBufferByteCount will contain the number of bytes needed to hold the string.

@param outUTF8StringBuffer Buffer where UTF8 string will be stored @param ioUTF8StringBufferSizeInElements Pass in the size, in elements, of outUTF8StringStorage. Returns the number of elements copied. Includes terminating 0.

@return suiteError_InvalidParms One of the params is invalid @return suiteError_StringBufferTooSmall The passed in string buffer is too small. ioUTF8StringBufferByteCount will contain the number of bytes needed to copy this string. @return suiteError_NoError The string has been copied. ioUTF8StringBufferByteCount contains the number of bytes copied.

AllocateFromUTF16: Option<unsafe extern "C" fn(inUTF16String: *const prUTF16Char, outSDKString: *mut PrSDKString) -> prSuiteError>

This will allocate an SDKString from a passed in null terminated string.

@param inUTF16String null terminated UTF16 string to copy into the SDK string @param ioSDKString this passed in SDK string will receive the new allocated string - you must dispose of this sdk string

@return suiteError_StringNotFound this string has not been allocated, or may have already been disposed @return suiteError_InvalidParms one of the params is invalid

CopyToUTF16String: Option<unsafe extern "C" fn(inSDKString: *const PrSDKString, outUTF16StringBuffer: *mut prUTF16Char, ioUTF16StringBufferSizeInElements: *mut csSDK_uint32) -> prSuiteError>

This will copy an SDKString into a UTF16 null terminated string if ioUTF16StringBufferByteCount reports enough bytes in the string buffer to copy. If there are not enough bytes - suiteError_StringBufferTooSmall will be returned and ioUTF16StringBufferByteCount will contain the number of bytes needed to hold the string.

@param outUTF16StringBuffer Buffer where UTF16 string will be stored @param ioUTF16StringBufferSizeInElements Pass in the size, in elements, of outUTF16StringStorage. Returns the number of elements copied. Includes terminating 0.

@return suiteError_InvalidParms One of the params is invalid @return suiteError_StringBufferTooSmall The passed in string buffer is too small. ioUTF16StringBufferByteCount will contain the number of bytes needed to copy this string. @return suiteError_NoError The string has been copied. ioUTF16StringBufferByteCount contains the number of bytes copied.