PrSDKTimeSuite

Struct PrSDKTimeSuite 

#[repr(C, packed(1))]
pub struct PrSDKTimeSuite { pub GetTicksPerSecond: Option<unsafe extern "C" fn(outTicksPerSec: *mut PrTime) -> prSuiteError>, pub GetTicksPerVideoFrame: Option<unsafe extern "C" fn(inVideoFrameRate: PrVideoFrameRates, outTicksPerFrame: *mut PrTime) -> prSuiteError>, pub GetTicksPerAudioSample: Option<unsafe extern "C" fn(inSampleRate: f32, outTicksPerSample: *mut PrTime) -> prSuiteError>, }

Fields

GetTicksPerSecond: Option<unsafe extern "C" fn(outTicksPerSec: *mut PrTime) -> prSuiteError>

Get the current ticks per second. This is guaranteed to be constant for the duration of runtime.

@param outTickPerSec on return, the number of time ticks per second.

GetTicksPerVideoFrame: Option<unsafe extern "C" fn(inVideoFrameRate: PrVideoFrameRates, outTicksPerFrame: *mut PrTime) -> prSuiteError>

Get the number of ticks in a video frame rate.

@param inFrameRate an enum value for a video frame rate. @param outTicksPerFrame on return, the number of time ticks per frame.

GetTicksPerAudioSample: Option<unsafe extern "C" fn(inSampleRate: f32, outTicksPerSample: *mut PrTime) -> prSuiteError>

Get the number of ticks in an audio sample rate.

@param inSampleRate the audio sample rate as a float. @param outTicksPerSample on return, the number of time ticks per sample. @return kPrTimeSuite_RoundedAudioRate is returned if the requested audio sample rate is not an even divisor of the base tick count and therefore times in this rate will not be exact.