imFrameFormat

Struct imFrameFormat 

#[repr(C, packed(1))]
pub struct imFrameFormat { pub inFrameWidth: csSDK_int32, pub inFrameHeight: csSDK_int32, pub inPixelFormat: PrPixelFormat, }
This struct defines a specific frame format that is being requested fromt the importer. Any member can be 0, which means that any value is an acceptable match. For instance, the host might ask for a specific width and height, but pass 0 as the pixel format, meaning it can accept any pixel format.

Fields

inFrameWidth: csSDK_int32inFrameHeight: csSDK_int32inPixelFormat: PrPixelFormat