PF_CallbackFunc

Type Alias PF_CallbackFunc 

pub type PF_CallbackFunc = *mut PF_YouMustCastThisToActualFunctionType;
Previous versions of PF_CallbackFunc were defined using varargs in attempt to enforce the effect_ref passed as the first argument to all callbacks. The actual host implementations are generally not varargs, and on some platforms the calling conventions between normal C ABI and C varargs ABI are not compatible. If your code is trying to call through a PF_CallbackFunc it is unsafe; with this definition it will now no longer compile. To fix, cast to the proper API signature before calling. Or better, use the extensive Suite implementations which are explicitly typed