Type Alias PF_IteratePixel8Func

pub type PF_IteratePixel8Func = Option<unsafe extern "C" fn(refconP: *mut c_void, xL: A_long, yL: A_long, inP: *mut PF_Pixel, outP: *mut PF_Pixel) -> PF_Err>;
prototypes for PF_ITERATE8 and PF_ITERATE16 pixel functions

the user of PF_ITERATE provides a refcon; After Effects may distribute iteration across multiple threads, so any data pointed to by refconL should be read-only or properly synchronized

inP is writable only if the world you pass to PF_ITERATE() is PF_WorldFlag_WRITEABLE

Aliased Type

pub enum PF_IteratePixel8Func {
    None,
    Some(unsafe extern "C" fn(*mut c_void, i32, i32, *mut PF_Pixel, *mut PF_Pixel) -> i32),
}

Variants

1.0.0

None

No value.

1.0.0

Some(unsafe extern "C" fn(*mut c_void, i32, i32, *mut PF_Pixel, *mut PF_Pixel) -> i32)

Some value of type T.