PrTime

Type Alias PrTime 

pub type PrTime = prInt64;
Time overview:

Premiere uses a tick-based time counter that is stored in a signed 64-bit integer. The current number of ticks per second must be retrieved using the callback in this suite, but is guaranteed to be constant for the duration of runtime.