SegmentNodePropertyCallback

Type Alias SegmentNodePropertyCallback 

pub type SegmentNodePropertyCallback = Option<unsafe extern "C" fn(inPluginObject: csSDK_int32, inKey: *const c_char, inValue: *const prUTF8Char) -> prSuiteError>;
This callback function is used by the property query methods. Iteration can be cancelled at any time by returning a result other than malNoError.

@param inPluginObject A value (such as “this”) passed by the plugin in the original call and passed back in the callback. May be NULL. @param inKey The key for the property @param inValue The value for the property

Aliased Type

pub enum SegmentNodePropertyCallback {
    None,
    Some(unsafe extern "C" fn(i32, *const i8, *const u8) -> i32),
}

Variants

1.0.0

None

No value.

1.0.0

Some(unsafe extern "C" fn(i32, *const i8, *const u8) -> i32)

Some value of type T.