#[repr(C)]pub struct PF_ANSICallbacks {Show 20 fields
pub atan: Option<unsafe extern "C" fn(arg1: A_FpLong) -> A_FpLong>,
pub atan2: Option<unsafe extern "C" fn(y: A_FpLong, x: A_FpLong) -> A_FpLong>,
pub ceil: Option<unsafe extern "C" fn(arg1: A_FpLong) -> A_FpLong>,
pub cos: Option<unsafe extern "C" fn(arg1: A_FpLong) -> A_FpLong>,
pub exp: Option<unsafe extern "C" fn(arg1: A_FpLong) -> A_FpLong>,
pub fabs: Option<unsafe extern "C" fn(arg1: A_FpLong) -> A_FpLong>,
pub floor: Option<unsafe extern "C" fn(arg1: A_FpLong) -> A_FpLong>,
pub fmod: Option<unsafe extern "C" fn(x: A_FpLong, y: A_FpLong) -> A_FpLong>,
pub hypot: Option<unsafe extern "C" fn(x: A_FpLong, y: A_FpLong) -> A_FpLong>,
pub log: Option<unsafe extern "C" fn(arg1: A_FpLong) -> A_FpLong>,
pub log10: Option<unsafe extern "C" fn(arg1: A_FpLong) -> A_FpLong>,
pub pow: Option<unsafe extern "C" fn(x: A_FpLong, y: A_FpLong) -> A_FpLong>,
pub sin: Option<unsafe extern "C" fn(arg1: A_FpLong) -> A_FpLong>,
pub sqrt: Option<unsafe extern "C" fn(arg1: A_FpLong) -> A_FpLong>,
pub tan: Option<unsafe extern "C" fn(arg1: A_FpLong) -> A_FpLong>,
pub sprintf: Option<unsafe extern "C" fn(arg1: *mut A_char, arg2: *const A_char, ...) -> c_int>,
pub strcpy: Option<unsafe extern "C" fn(arg1: *mut A_char, arg2: *const A_char) -> *mut A_char>,
pub asin: Option<unsafe extern "C" fn(arg1: A_FpLong) -> A_FpLong>,
pub acos: Option<unsafe extern "C" fn(arg1: A_FpLong) -> A_FpLong>,
pub ansi_procs: [A_long; 1],
}Expand description
––––– ANSI Routines Block –––––
Within the callback routines block there is a block of ANSI routines, so that the filter will not need to link with the ANSI library. The following structure describes that block and is included in the larger Callback Routines block below.
All angles are expressed in radians; use PF_RAD_PER_DEGREE to convert from degrees to radians, if necessary. Be aware that angle parameter types use degrees (in fixed point).
Sprintf and strcpy are provided to facilitate string usage, such as printing for names and supervised controls.
None of these callbacks vary based on the Quality setting.
Fields
atan: Option<unsafe extern "C" fn(arg1: A_FpLong) -> A_FpLong>atan2: Option<unsafe extern "C" fn(y: A_FpLong, x: A_FpLong) -> A_FpLong>ceil: Option<unsafe extern "C" fn(arg1: A_FpLong) -> A_FpLong>cos: Option<unsafe extern "C" fn(arg1: A_FpLong) -> A_FpLong>exp: Option<unsafe extern "C" fn(arg1: A_FpLong) -> A_FpLong>fabs: Option<unsafe extern "C" fn(arg1: A_FpLong) -> A_FpLong>floor: Option<unsafe extern "C" fn(arg1: A_FpLong) -> A_FpLong>fmod: Option<unsafe extern "C" fn(x: A_FpLong, y: A_FpLong) -> A_FpLong>hypot: Option<unsafe extern "C" fn(x: A_FpLong, y: A_FpLong) -> A_FpLong>log: Option<unsafe extern "C" fn(arg1: A_FpLong) -> A_FpLong>log10: Option<unsafe extern "C" fn(arg1: A_FpLong) -> A_FpLong>pow: Option<unsafe extern "C" fn(x: A_FpLong, y: A_FpLong) -> A_FpLong>sin: Option<unsafe extern "C" fn(arg1: A_FpLong) -> A_FpLong>sqrt: Option<unsafe extern "C" fn(arg1: A_FpLong) -> A_FpLong>tan: Option<unsafe extern "C" fn(arg1: A_FpLong) -> A_FpLong>sprintf: Option<unsafe extern "C" fn(arg1: *mut A_char, arg2: *const A_char, ...) -> c_int>strcpy: Option<unsafe extern "C" fn(arg1: *mut A_char, arg2: *const A_char) -> *mut A_char>asin: Option<unsafe extern "C" fn(arg1: A_FpLong) -> A_FpLong>acos: Option<unsafe extern "C" fn(arg1: A_FpLong) -> A_FpLong>ansi_procs: [A_long; 1]Trait Implementations
Sourceimpl Clone for PF_ANSICallbacks
impl Clone for PF_ANSICallbacks
Sourcefn clone(&self) -> PF_ANSICallbacks
fn clone(&self) -> PF_ANSICallbacks
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PF_ANSICallbacks
impl Debug for PF_ANSICallbacks
impl Copy for PF_ANSICallbacks