#[repr(C)]pub struct PF_PointDef {
pub x_value: PF_Fixed,
pub y_value: PF_Fixed,
pub reserved: [A_char; 3],
pub restrict_bounds: PF_Boolean,
pub x_dephault: PF_Fixed,
pub y_dephault: PF_Fixed,
}Expand description
Point – PF_Param_POINT
The values for the point use the source’s coordinate system, with the origin at the top left. The values are expressed in fixed point, with 16 bits of fractional precision (out of a total of 32 bits).
The dephaults (sorry) are expressed as percentages (with 16 bits of fraction) with the origin at the top left. The percent can be negative, but should not be smaller than -600%. It should not be greater than 600%.
If restrict_bounds is TRUE, the user will not be allowed to specify points outside the bounds of the layer to which they are applying the effect. If this is TRUE, the dephaults should be between 0.0 and 100.0.
Fields
x_value: PF_Fixedy_value: PF_Fixedreserved: [A_char; 3]restrict_bounds: PF_Booleanx_dephault: PF_Fixedy_dephault: PF_FixedTrait Implementations
Sourceimpl Clone for PF_PointDef
impl Clone for PF_PointDef
Sourcefn clone(&self) -> PF_PointDef
fn clone(&self) -> PF_PointDef
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PF_PointDef
impl Debug for PF_PointDef
impl Copy for PF_PointDef