#[repr(C)]pub struct PF_TransitionSuite {
pub RegisterTransitionInputParam: Option<unsafe extern "C" fn(inEffectRef: PF_ProgPtr, inIndex: PF_ParamIndex) -> PF_Err>,
pub RegisterTransitionStartParam: Option<unsafe extern "C" fn(inEffectRef: PF_ProgPtr, inIndex: PF_ParamIndex) -> PF_Err>,
pub RegisterTransitionEndParam: Option<unsafe extern "C" fn(inEffectRef: PF_ProgPtr, inIndex: PF_ParamIndex) -> PF_Err>,
}Fields
RegisterTransitionInputParam: Option<unsafe extern "C" fn(inEffectRef: PF_ProgPtr, inIndex: PF_ParamIndex) -> PF_Err>Register an effect as a transition using the passed in input layer as the outgoing clip. When registered the effect will be available to be dragged directly onto clip ends rather than only applied to layers.
RegisterTransitionStartParam: Option<unsafe extern "C" fn(inEffectRef: PF_ProgPtr, inIndex: PF_ParamIndex) -> PF_Err>Register a PF_ADD_FLOAT_SLIDER parameter to receive changes to the start of the transition region through the PF_Cmd_USER_CHANGED_PARAM command.
RegisterTransitionEndParam: Option<unsafe extern "C" fn(inEffectRef: PF_ProgPtr, inIndex: PF_ParamIndex) -> PF_Err>Register a PF_ADD_FLOAT_SLIDER parameter to receive changes to the end of the transition region through the PF_Cmd_USER_CHANGED_PARAM command.