#[repr(C, packed(1))]pub struct PrSDKPlayModuleDeviceControlSuite {
pub Seek: Option<unsafe extern "C" fn(inDeviceID: PlayModuleDeviceID) -> prSuiteError>,
pub Arm: Option<unsafe extern "C" fn(inDeviceID: PlayModuleDeviceID) -> prSuiteError>,
pub Record: Option<unsafe extern "C" fn(inDeviceID: PlayModuleDeviceID) -> prSuiteError>,
pub Stop: Option<unsafe extern "C" fn(inDeviceID: PlayModuleDeviceID) -> prSuiteError>,
}Expand description
Playmod Device Control overview:
This suite is provided so that play modules can control a hardware device during “Export To Tape.” The necessary DeviceControlID will only be passed down when a transmit is requested. The player must then call all of the methods in this suite, in the order in which they are listed.
Fields
Seek: Option<unsafe extern "C" fn(inDeviceID: PlayModuleDeviceID) -> prSuiteError>Tell the device to seek to the appropriate location.
@return kPrDeviceControlResult_Success or kPrDeviceControlResult_IllegalCallSequence.
Arm: Option<unsafe extern "C" fn(inDeviceID: PlayModuleDeviceID) -> prSuiteError>Tell the device to prepare to record.
@return kPrDeviceControlResult_Success or kPrDeviceControlResult_IllegalCallSequence.
Record: Option<unsafe extern "C" fn(inDeviceID: PlayModuleDeviceID) -> prSuiteError>Tell the device to start recording.
@return kPrDeviceControlResult_Success or kPrDeviceControlResult_IllegalCallSequence.
Stop: Option<unsafe extern "C" fn(inDeviceID: PlayModuleDeviceID) -> prSuiteError>Tell the device to stop recording. This also cleans up the device control object, so it is not available after this call.
@return kPrDeviceControlResult_Success or kPrDeviceControlResult_IllegalCallSequence.