#[repr(C, packed(1))]pub struct imFrameFormat {
pub inFrameWidth: csSDK_int32,
pub inFrameHeight: csSDK_int32,
pub inPixelFormat: PrPixelFormat,
}Expand description
This struct defines a specific frame format that is being requested fromt the importer. Any member can be 0, which means that any value is an acceptable match. For instance, the host might ask for a specific width and height, but pass 0 as the pixel format, meaning it can accept any pixel format.
Fields
inFrameWidth: csSDK_int32inFrameHeight: csSDK_int32inPixelFormat: PrPixelFormatTrait Implementations
Sourceimpl Clone for imFrameFormat
impl Clone for imFrameFormat
Sourcefn clone(&self) -> imFrameFormat
fn clone(&self) -> imFrameFormat
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for imFrameFormat
impl Debug for imFrameFormat
impl Copy for imFrameFormat