pub type PrAudioDataType = c_uint;Expand description
This is not the sample type of the underlying audio - this is the sample type that is returned in the calls that support variable audio types. If the type is not explicitly called out as variable, then it is Float32.